@@ -25,7 +25,6 @@
 #include "gnome-vfs-mime.h"
 #include "gnome-vfs-private-utils.h"
 
-#include <ctype.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <stdio.h>
@@ -33,6 +32,11 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
+#include <glib/garray.h>
+#include <glib/gmessages.h>
+#include <glib/gstrfuncs.h>
+#include <glib/gthread.h>
+#include <glib/gutils.h>
 
 static gboolean
 is_octal_digit (char ch)
@@ -93,7 +97,7 @@ read_hex_byte (const char **pos)
 		if (**pos >= '0' && **pos <= '9') {
 			retval += **pos - '0';
 		} else {
-			retval += tolower (**pos) - 'a' + 10;
+			retval += g_ascii_tolower (**pos) - 'a' + 10;
 		}
 
   		(*pos)++;
@@ -118,7 +122,7 @@ read_string_val (const char *scanner, char *intobuf, int max_len, guint16 *into_
 	intobufend = intobuf + max_len - 1;
 	*into_len = 0;
 
-	while (*scanner && !isspace ((unsigned char)*scanner) && *scanner != '#') {
+	while (*scanner && !g_ascii_isspace (*scanner) && *scanner != '#') {
 		ch = *scanner++;
 
 		switch (ch) {
@@ -187,7 +191,7 @@ read_num_val(const char **offset, int bsize, int *result)
 	const char *scanner = *offset;
 	
 	if (*scanner == '0') {
-		if (tolower (scanner[1]) == 'x') {
+		if (g_ascii_tolower (scanner[1]) == 'x') {
 			fmttype = 'x';
 		} else {
 			fmttype = 'o';
@@ -224,7 +228,7 @@ read_num_val(const char **offset, int bsize, int *result)
 		break;
 	}
 
-	while (**offset && !isspace ((guchar)**offset)) {
+	while (**offset && !g_ascii_isspace (**offset)) {
 		(*offset)++;
 	}
 
@@ -234,7 +238,7 @@ read_num_val(const char **offset, int bsize, int *result)
 static const char *
 eat_white_space (const char *scanner)
 {
-	while (*scanner && isspace ((guchar)*scanner)) {
+	while (g_ascii_isspace (*scanner)) {
 		scanner++;
 	}
 	return scanner;
@@ -286,7 +290,7 @@ gnome_vfs_mime_magic_parse (const gchar *filename, gint *nents)
 			continue;
 		}
 
-		if (!isdigit ((guchar)*scanner)) {
+		if (!g_ascii_isdigit (*scanner)) {
 			continue;
 		}
 
@@ -295,7 +299,7 @@ gnome_vfs_mime_magic_parse (const gchar *filename, gint *nents)
 		}
 		newent.range_end = newent.range_start;
 
-		while (*scanner && isdigit ((guchar)*scanner)) {
+		while (g_ascii_isdigit (*scanner)) {
 			scanner++; /* eat the offset */
 		}
 
@@ -307,7 +311,7 @@ gnome_vfs_mime_magic_parse (const gchar *filename, gint *nents)
 			}
 		}
 
-		while (*scanner && !isspace ((guchar)*scanner)) {
+		while (*scanner && !g_ascii_isspace (*scanner)) {
 			scanner++; /* eat the offset */
 		}
 
@@ -416,7 +420,7 @@ gnome_vfs_mime_magic_parse (const gchar *filename, gint *nents)
 
 		g_snprintf (newent.mimetype, sizeof (newent.mimetype), "%s", scanner);
 		bsize = strlen (newent.mimetype) - 1;
-		while (newent.mimetype [bsize] && isspace ((guchar)(newent.mimetype [bsize]))) {
+		while (newent.mimetype [bsize] && g_ascii_isspace (newent.mimetype [bsize])) {
 			newent.mimetype [bsize--] = '\0';
 		}
 
@@ -608,7 +612,7 @@ print_escaped_string (const guchar *string, int length)
 		if (*string == '\\' || *string == '#') {
 			/* escape \, #, etc. properly */
 			printf ("\\%c", *string);
-		} else if (isprint (*string) && *string > ' ') {
+		} else if (g_ascii_isgraph (*string)) {
 			/* everything printable except for white space can go directly */
 			printf ("%c", *string);
 		} else {
@@ -731,7 +735,7 @@ gnome_vfs_sniff_buffer_looks_like_text (GnomeVFSMimeSniffBuffer *sniff_buffer)
 	
 	for (index = 0; index < sniff_buffer->buffer_length - 3; index++) {
 		ch = sniff_buffer->buffer[index];
-		if (!isprint (ch) && !isspace(ch)) {
+		if (!g_ascii_isprint (ch) && !g_ascii_isspace (ch)) {
 			/* check if we are dealing with UTF-8 text
 			 * 
 			 *	 bytes | bits | representation
