@@ -24,13 +24,16 @@
 #include <config.h>
 
 #include <libgnomevfs/gnome-vfs-init.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-mime-magic.h>
+#include <libgnomevfs/gnome-vfs-mime-utils.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
 #include <stdio.h>
 #include <string.h>
 
+#include <sys/stat.h>
+
 int
 main (int argc, char **argv)
 {
@@ -116,7 +119,6 @@ main (int argc, char **argv)
 	
 		printf ("looks like %s is %s\n", *argv, result);
 		gnome_vfs_uri_unref (uri);
-		g_free (uri_string);
 	}
 	
 	return 0;
